﻿using System;

using CMS.TranslationServices;
using CMS.IO;

namespace SampleTranslationServices
{
    /// <summary>
    /// Sample machine translation service.
    /// </summary>
    public class SampleMachineTranslationService : AbstractMachineTranslationService
    {
        /// <summary>
        /// Translates given text from source language to target language.
        /// </summary>
        /// <param name="text">Text to translate</param>
        /// <param name="sourceLang">Source language</param>
        /// <param name="targetLang">Target language</param>
        public override string Translate(string text, string sourceLang, string targetLang)
        {
            // "Translates" the text to upper case
            return text.ToUpper();
        }


        /// <summary>
        /// Detects the language of the source text.
        /// </summary>
        /// <param name="text">Text to process</param>
        public override string Detect(string text)
        {
            // Use your service to detect the language
            return "en-US";
        }


        /// <summary>
        /// Returns stream of sound generated by text-to-speech service if supported.
        /// </summary>
        /// <param name="text"></param>
        /// <param name="lang"></param>
        public override Stream Speak(string text, string lang)
        {
            // My provider does not support Text-to-speech
            throw new NotImplementedException();
        }


        /// <summary>
        /// Checks the necessary prerequisities of the service (i.e. availability of credentials for contacting service atc.).
        /// </summary>
        public override bool IsAvailable()
        {
            // This sample provider does not require any settings and does not depend on
            // any other service, therefore is always available.
            return true;
        }
    }
}